@@ -3,7 +3,7 @@
 Open Asset Import Library (assimp)
 ---------------------------------------------------------------------------
 
-Copyright (c) 2006-2024, assimp team
+Copyright (c) 2006-2025, assimp team
 
 All rights reserved.
 
@@ -79,7 +79,7 @@ TEST_F(utColladaExport, testExportCamera) {
 
     EXPECT_EQ(AI_SUCCESS, ex->Export(pTest, "collada", file));
     const unsigned int origNumCams(pTest->mNumCameras);
-    //std::vector<float> origFOV;
+
     std::unique_ptr<float[]> origFOV(new float[origNumCams]);
     std::unique_ptr<float[]> orifClipPlaneNear(new float[origNumCams]);
     std::unique_ptr<float[]> orifClipPlaneFar(new float[origNumCams]);
@@ -114,6 +114,9 @@ TEST_F(utColladaExport, testExportCamera) {
         EXPECT_FLOAT_EQ(pos[i].y, read->mPosition.y);
         EXPECT_FLOAT_EQ(pos[i].z, read->mPosition.z);
     }
+
+    // Cleanup, delete the exported file
+    EXPECT_EQ(0, std::remove(file));
 }
 
 // ------------------------------------------------------------------------------------------------
@@ -220,6 +223,9 @@ TEST_F(utColladaExport, testExportLight) {
         EXPECT_NEAR(orig->mAngleInnerCone, read->mAngleInnerCone, 0.001);
         EXPECT_NEAR(orig->mAngleOuterCone, read->mAngleOuterCone, 0.001);
     }
+
+    // Cleanup, delete the exported file
+    EXPECT_EQ(0, std::remove(file));
 }
 
 #endif // ASSIMP_BUILD_NO_EXPORT
