@@ -3,7 +3,7 @@
 Open Asset Import Library (assimp)
 ---------------------------------------------------------------------------
 
-Copyright (c) 2006-2024, assimp team
+Copyright (c) 2006-2025, assimp team
 
 All rights reserved.
 
@@ -896,6 +896,27 @@ TEST_F(utglTF2ImportExport, import_dracoEncoded) {
         ASSERT_TRUE(scene->mMetaData->Get(AI_METADATA_SOURCE_GENERATOR, generator));
         ASSERT_EQ(strcmp(generator.C_Str(), "COLLADA2GLTF"), 0);
     }
+#endif
+    const aiScene *robotScene = importer.ReadFile(ASSIMP_TEST_MODELS_DIR "/glTF2/draco/robot.glb",
+        aiProcess_ValidateDataStructure);
+#ifndef ASSIMP_ENABLE_DRACO
+    // No draco support, scene should not load
+    ASSERT_EQ(robotScene, nullptr);
+#else
+    ASSERT_NE(robotScene, nullptr);
+    ASSERT_NE(robotScene->mMetaData, nullptr);
+    {
+        ASSERT_TRUE(robotScene->mMetaData->HasKey(AI_METADATA_SOURCE_FORMAT));
+        aiString format;
+        ASSERT_TRUE(robotScene->mMetaData->Get(AI_METADATA_SOURCE_FORMAT, format));
+        ASSERT_EQ(strcmp(format.C_Str(), "glTF2 Importer"), 0);
+    }
+    {
+        ASSERT_TRUE(robotScene->mMetaData->HasKey(AI_METADATA_SOURCE_FORMAT_VERSION));
+        aiString version;
+        ASSERT_TRUE(robotScene->mMetaData->Get(AI_METADATA_SOURCE_FORMAT_VERSION, version));
+        ASSERT_EQ(strcmp(version.C_Str(), "2.0"), 0);
+    }
 #endif
 }
 
@@ -912,8 +933,8 @@ TEST_F(utglTF2ImportExport, wrongTypes) {
         TUPLE("/glTF2/wrongTypes/badString.gltf", "string", "name", "scenes[0]"),
         TUPLE("/glTF2/wrongTypes/badUint.gltf", "uint", "index", "materials[0]"),
         TUPLE("/glTF2/wrongTypes/badNumber.gltf", "number", "scale", "materials[0]"),
-        TUPLE("/glTF2/wrongTypes/badObject.gltf", "object", "pbrMetallicRoughness", "materials[0]"),
-        TUPLE("/glTF2/wrongTypes/badExtension.gltf", "object", "KHR_texture_transform", "materials[0]")
+        //TUPLE("/glTF2/wrongTypes/badObject.gltf", "object", "pbrMetallicRoughness", "materials[0]"),
+        //TUPLE("/glTF2/wrongTypes/badExtension.gltf", "object", "KHR_texture_transform", "materials[0]")
 #undef TUPLE
     };
     for (const auto& tuple : wrongTypes)
@@ -931,6 +952,28 @@ TEST_F(utglTF2ImportExport, wrongTypes) {
     }
 }
 
+TEST_F(utglTF2ImportExport, wrongObject) {
+    // Deliberately broken version of the BoxTextured.gltf asset.
+    using tup_T = std::tuple<std::string, std::string, std::string, std::string>;
+    std::vector<tup_T> wrongTypes = {
+#ifdef __cpp_lib_constexpr_tuple
+#define TUPLE(x, y, z, w) \
+    { x, y, z, w }
+#else
+#define TUPLE(x, y, z, w) tup_T(x, y, z, w)
+#endif
+    TUPLE("/glTF2/wrongTypes/badObject.gltf", "object", "pbrMetallicRoughness", "materials[0]"),
+    TUPLE("/glTF2/wrongTypes/badExtension.gltf", "object", "KHR_texture_transform", "materials[0]")
+#undef TUPLE
+    };
+    for (const auto &tuple : wrongTypes) {
+        const auto &file = std::get<0>(tuple);
+        Assimp::Importer importer;
+        const aiScene *scene = importer.ReadFile(ASSIMP_TEST_MODELS_DIR + file, aiProcess_ValidateDataStructure);
+        ASSERT_NE(scene, nullptr);
+    }
+}
+
 namespace {
     /// This class provides a fake schema to the GLTF importer.
     /// It just checks that the file has a top-level "scene" property which is an integer.
